@@ -1,6 +1,6 @@
 from fastapi import FastAPI
 from soco_encoders.http.routes.router import api_router
-from soco_encoders.http.config import EnvVars
+from soco_encoders.config import EnvVars
 from soco_encoders.http.event_handlers import (start_app_handler, stop_app_handler)
 
 
