@@ -33,19 +33,21 @@ class EncoderLoader(object):
         return model
 
     @staticmethod
-    def load_model(model_family, model_id, use_gpu, region='us'):
+    def load_model(model_family, model_id, use_gpu, region='us', device_name='cpu'):
         if not torch.cuda.is_available():
             use_gpu = False
 
         bucket = CloudBucket(region)
         model_dir = bucket.download_config(model_family, model_id)
         config = json.load(open(os.path.join(model_dir, 'config.json')))
+        if device_name.startswith("cuda") or device_name.startswith("gpu"):
+            device = torch.device(device_name)
+        else:
+            device_check = DeviceCheck()
+            device_name, device_ids = device_check.get_device_by_model(model_id, n_gpu=1 if use_gpu else 0)
+            device_name = '{}:{}'.format(device_name, device_ids[0]) if len(device_ids) == 1 else device_name
+            device = torch.device(device_name)
 
-        device_check = DeviceCheck()
-        device_name, device_ids = device_check.get_device_by_model(model_id, n_gpu=1 if use_gpu else 0)
-        device_name = '{}:{}'.format(device_name, device_ids[0]) if len(device_ids) == 1 else device_name
-
-        device = torch.device(device_name)
         config['use_gpu'] = False if device_name == 'cpu' else True
         config['device'] = device
         config = Pack(config)
