@@ -1,5 +1,5 @@
 from torch import nn
-from transformers import  BertModel, BertTokenizer
+from transformers import  BertModel, BertTokenizer, AlbertTokenizer, BertTokenizerFast
 import json
 from typing import Union, Tuple, List, Dict
 import os
@@ -23,7 +23,10 @@ class BERT(nn.Module):
         self.max_seq_length = max_seq_length
 
         self.bert = BertModel.from_pretrained(model_name_or_path)
-        self.tokenizer = BertTokenizer.from_pretrained(model_name_or_path, do_lower_case=do_lower_case)
+        try:
+            self.tokenizer = BertTokenizerFast.from_pretrained(model_name_or_path, do_lower_case=do_lower_case)
+        except:
+            self.tokenizer = AlbertTokenizer.from_pretrained(model_name_or_path, do_lower_case=do_lower_case)
         self.cls_token_id = self.tokenizer.convert_tokens_to_ids([self.tokenizer.cls_token])[0]
         self.sep_token_id = self.tokenizer.convert_tokens_to_ids([self.tokenizer.sep_token])[0]
 
